@@ -8,7 +8,6 @@ Admin extension that automtically creates CRUD interfaces for all database model
 """
 
 import os.path
-from pyramid_handlers import action
 from pyramid.response import Response
 
 from pyramid.httpexceptions import HTTPFound
@@ -75,7 +74,7 @@ def add_admin_handler(config, db_session, models=None, route_name_prefix='',
     all_models = []
 
     if dict == type(models):
-        for appname, app_models in models.iteritems():
+        for appname, app_models in list(models.items()):
             for model in app_models:
                 all_models.append(model)
                 tablename = model.__tablename__
@@ -108,7 +107,7 @@ def add_admin_handler(config, db_session, models=None, route_name_prefix='',
                 # If target column is integer, set the column next to it as display column,
                 # for non-int columns keep the display column same as the db column
                 if int == list(FK.foreign_keys)[0].column.table.columns[db_col].type.python_type:
-                    table_cols = list(FK.foreign_keys)[0].column.table.columns.keys()
+                    table_cols = list(list(FK.foreign_keys)[0].column.table.columns.keys())
                     d_idx = table_cols.index(db_col) + 1
                     if len(table_cols) > d_idx:
                         display_col = table_cols[d_idx]
